# Reverse Symmetric Graph

[![pipeline status](https://gitlab.com/vepain/pyrevsymg/badges/master/pipeline.svg)](https://gitlab.com/vepain/pyrevsymg/-/commits/master)
[![coverage report](https://gitlab.com/vepain/pyrevsymg/badges/master/coverage.svg)](https://gitlab.com/vepain/pyrevsymg/-/commits/master)
[![Latest Release](https://gitlab.com/vepain/pyrevsymg/-/badges/release.svg)](https://gitlab.com/vepain/pyrevsymg/-/releases)

 <img src="docs/img/revsymg_logo_transp.png" alt="revsymg logo"
width="200" height="200">


## Installation

See [INSTALL.md](docs/INSTALL.md) for more details.


## Usage

* [ ] DOC: usage and docs


## Changelog

See [CHANGELOG.md](docs/CHANGELOG.md) for details.


## Next

See [TODO.md](docs/TODO.md) for details.


## Contributing

See [CONTRIBUTING.md](docs/CONTRIBUTING.md) file.


## References

* Inspired by [graph-tool](https://graph-tool.skewed.de/)


## Licence

This work is licensed under a GNU-GPLv3 licence

See [LICENCE](LICENCE)